@@ -17,7 +17,7 @@ from collections import namedtuple
 import newrelic.core.attribute as attribute
 import newrelic.core.trace_node
 
-from newrelic.common import constants, system_info
+from newrelic.common import system_info
 from newrelic.core.database_utils import sql_statement, explain_plan
 from newrelic.core.node_mixin import DatastoreNodeMixin
 from newrelic.core.metric import TimeMetric
@@ -67,7 +67,7 @@ class DatabaseNode(_DatabaseNode, DatastoreNodeMixin):
 
     @property
     def instance_hostname(self):
-        if self.host in constants.LOCALHOST_EQUIVALENTS:
+        if self.host in system_info.LOCALHOST_EQUIVALENTS:
             hostname = system_info.gethostname()
         else:
             hostname = self.host
@@ -259,4 +259,8 @@ class DatabaseNode(_DatabaseNode, DatastoreNodeMixin):
                     'db.statement', sql, max_length=2000, ending='...')
 
         self.agent_attributes['db.statement'] = sql
+
+        if self.target:
+            self.agent_attributes["db.collection"] = self.target
+
         return super(DatabaseNode, self).span_event(*args, **kwargs)
