@@ -14,6 +14,18 @@
 
 from collections import namedtuple
 
-ErrorNode = namedtuple('ErrorNode',
-        ['timestamp', 'type', 'message', 'expected', 'span_id', 'stack_trace', 'custom_params',
-        'file_name', 'line_number', 'source'])
+ErrorNode = namedtuple(
+    "ErrorNode",
+    [
+        "timestamp",
+        "type",
+        "message",
+        "expected",
+        "span_id",
+        "stack_trace",
+        "custom_params",
+        "file_name",
+        "line_number",
+        "source",
+    ],
+)
