@@ -452,6 +452,10 @@ class TransactionNode(_TransactionNode):
         def _add_if_not_empty(key, value):
             if value:
                 intrinsics[key] = value
+        
+        apdex_perf_zone = self.apdex_perf_zone()
+        _add_if_not_empty('apdexPerfZone', apdex_perf_zone)
+        _add_if_not_empty('nr.apdexPerfZone', apdex_perf_zone)
 
         if self.errors:
             intrinsics['error'] = True
@@ -467,8 +471,6 @@ class TransactionNode(_TransactionNode):
                     ','.join(self.alternate_path_hashes))
             _add_if_not_empty('nr.referringTransactionGuid',
                     self.referring_transaction_guid)
-            _add_if_not_empty('nr.apdexPerfZone',
-                    self.apdex_perf_zone())
 
         if self.synthetics_resource_id:
             intrinsics['nr.guid'] = self.guid
