@@ -1,8 +1,28 @@
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import functools
 
-from newrelic.agent import (ExternalTrace, ObjectWrapper, current_transaction)
+from newrelic.packages import six
 
-def httplib_connect_wrapper(wrapped, instance, args, kwargs, scheme):
+from newrelic.api.external_trace import ExternalTrace
+from newrelic.api.transaction import current_transaction
+from newrelic.common.object_wrapper import ObjectWrapper
+
+
+def httplib_endheaders_wrapper(wrapped, instance, args, kwargs,
+        scheme, library):
     transaction = current_transaction()
 
     if transaction is None:
@@ -16,25 +36,10 @@ def httplib_connect_wrapper(wrapped, instance, args, kwargs, scheme):
 
     connection = instance
 
-    url = '%s://%s' % (scheme, connection.host)
+    if hasattr(connection, '_nr_library_info'):
+        library, scheme = connection._nr_library_info
 
-    with ExternalTrace(transaction, library='httplib', url=url) as tracer:
-        # Add the tracer to the connection object. The tracer will be
-        # used in getresponse() to add back into the external trace,
-        # after the trace has already completed, details from the
-        # response headers.
-
-        connection._nr_external_tracer = tracer
-
-        return wrapped(*args, **kwargs)
-
-def httplib_endheaders_wrapper(wrapped, instance, args, kwargs):
-    transaction = current_transaction()
-
-    if transaction is None:
-        return wrapped(*args, **kwargs)
-
-    connection = instance
+    url = '%s://%s:%s' % (scheme, connection.host, connection.port)
 
     # Check if the NR headers have already been added. This is just in
     # case a higher level library which uses httplib underneath so
@@ -43,21 +48,28 @@ def httplib_endheaders_wrapper(wrapped, instance, args, kwargs):
     try:
         skip_headers = getattr(connection, '_nr_skip_headers', False)
 
-        if skip_headers:
+        with ExternalTrace(library=library, url=url, source=wrapped) as tracer:
+            # Add the tracer to the connection object. The tracer will be
+            # used in getresponse() to add back into the external trace,
+            # after the trace has already completed, details from the
+            # response headers.
+            if not skip_headers and hasattr(
+                    tracer, 'generate_request_headers'):
+                outgoing_headers = tracer.generate_request_headers(transaction)
+                for header_name, header_value in outgoing_headers:
+                    connection.putheader(header_name, header_value)
+
+            connection._nr_external_tracer = tracer
+
             return wrapped(*args, **kwargs)
 
-        outgoing_headers = ExternalTrace.generate_request_headers(transaction)
-        for header_name, header_value in outgoing_headers:
-            connection.putheader(header_name, header_value)
-
-        return wrapped(*args, **kwargs)
-
     finally:
         try:
             del connection._nr_skip_headers
         except AttributeError:
             pass
 
+
 def httplib_getresponse_wrapper(wrapped, instance, args, kwargs):
     transaction = current_transaction()
 
@@ -79,11 +91,12 @@ def httplib_getresponse_wrapper(wrapped, instance, args, kwargs):
 
     del connection._nr_external_tracer
 
-    if hasattr(tracer, 'process_response_headers'):
-        tracer.process_response_headers(response.getheaders())
+    if hasattr(tracer, 'process_response'):
+        tracer.process_response(response.status, response.getheaders())
 
     return response
 
+
 def httplib_putheader_wrapper(wrapped, instance, args, kwargs):
     transaction = current_transaction()
 
@@ -94,7 +107,8 @@ def httplib_putheader_wrapper(wrapped, instance, args, kwargs):
     # it if we see either, but they should always both be getting set.
 
     def nr_header(header, *args, **kwargs):
-        return header.upper() in ('X-NEWRELIC-ID', 'X-NEWRELIC-TRANSACTION')
+        return header.upper() in ('NEWRELIC',
+            'X-NEWRELIC-ID', 'X-NEWRELIC-TRANSACTION')
 
     connection = instance
 
@@ -103,34 +117,32 @@ def httplib_putheader_wrapper(wrapped, instance, args, kwargs):
 
     return wrapped(*args, **kwargs)
 
+
 def instrument(module):
 
-    module.HTTPConnection.connect = ObjectWrapper(
-            module.HTTPConnection.connect,
-            None,
-            functools.partial(httplib_connect_wrapper, scheme='http')
-            )
-
-    module.HTTPSConnection.connect = ObjectWrapper(
-            module.HTTPSConnection.connect,
-            None,
-            functools.partial(httplib_connect_wrapper, scheme='https')
-            )
+    if six.PY2:
+        library = 'httplib'
+    else:
+        library = 'http'
 
     module.HTTPConnection.endheaders = ObjectWrapper(
             module.HTTPConnection.endheaders,
             None,
-            httplib_endheaders_wrapper
-            )
+            functools.partial(httplib_endheaders_wrapper, scheme='http',
+                    library=library))
+
+    module.HTTPSConnection.endheaders = ObjectWrapper(
+            module.HTTPConnection.endheaders,
+            None,
+            functools.partial(httplib_endheaders_wrapper, scheme='https',
+                    library=library))
 
     module.HTTPConnection.getresponse = ObjectWrapper(
             module.HTTPConnection.getresponse,
             None,
-            httplib_getresponse_wrapper
-            )
+            httplib_getresponse_wrapper)
 
     module.HTTPConnection.putheader = ObjectWrapper(
             module.HTTPConnection.putheader,
             None,
-            httplib_putheader_wrapper
-            )
+            httplib_putheader_wrapper)
