@@ -23,10 +23,10 @@ import uvicorn
 from testing_support.fixtures import (
     override_application_settings,
     raise_background_exceptions,
-    validate_transaction_errors,
-    validate_transaction_metrics,
     wait_for_background_threads,
 )
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
+from testing_support.validators.validate_transaction_errors import validate_transaction_errors
 from testing_support.sample_asgi_applications import (
     AppWithCall,
     AppWithCallRaw,
@@ -97,7 +97,7 @@ def port(app):
 
     thread = threading.Thread(target=server_run, daemon=True)
     thread.start()
-    ready.wait()
+    assert ready.wait(timeout=10)
     yield port
     _ = [loop.stop() for loop in loops]  # Stop all loops
     thread.join(timeout=1)
