@@ -13,9 +13,8 @@
 # limitations under the License.
 
 import pytest
-from testing_support.fixtures import (
-    function_not_called,
-    override_generic_settings,
+from testing_support.fixtures import function_not_called, override_generic_settings
+from testing_support.validators.validate_transaction_metrics import (
     validate_transaction_metrics,
 )
 
@@ -132,7 +131,7 @@ def test_context_propagation(event_loop, schedule, set_loop):
     # The agent should have removed all traces from the cache since
     # run_until_complete has terminated (all callbacks scheduled inside the
     # task have run)
-    assert not trace_cache()._cache
+    assert not trace_cache()
 
     # Assert that no exceptions have occurred
     assert not exceptions, exceptions
@@ -287,7 +286,7 @@ def test_transaction_exit_trace_cache(event_loop, fg):
 
     # The agent should have removed all traces from the cache since
     # run_until_complete has terminated
-    assert not trace_cache()._cache
+    assert not trace_cache()
 
     # Assert that no exceptions have occurred
     assert not exceptions, exceptions
