@@ -24,16 +24,22 @@ from testing_support.fixtures import (
     validate_error_event_attributes,
     validate_error_event_attributes_outside_transaction,
     validate_error_trace_attributes_outside_transaction,
-    validate_transaction_error_trace_attributes,
-    validate_transaction_event_attributes,
-    validate_transaction_trace_attributes,
 )
 from testing_support.validators.validate_span_events import validate_span_events
+from testing_support.validators.validate_transaction_error_trace_attributes import (
+    validate_transaction_error_trace_attributes,
+)
+from testing_support.validators.validate_transaction_event_attributes import (
+    validate_transaction_event_attributes,
+)
+from testing_support.validators.validate_transaction_trace_attributes import (
+    validate_transaction_trace_attributes,
+)
 
 from newrelic.api.application import application_instance as application
 from newrelic.api.message_transaction import message_transaction
 from newrelic.api.time_trace import notice_error
-from newrelic.api.transaction import add_custom_parameter
+from newrelic.api.transaction import add_custom_attribute
 from newrelic.api.wsgi_application import wsgi_application
 from newrelic.common.object_names import callable_name
 
@@ -87,7 +93,7 @@ TRACE_ERROR_AGENT_KEYS = [
 
 AGENT_KEYS_ALL = TRACE_ERROR_AGENT_KEYS + REQ_PARAMS
 
-TRANS_EVENT_INTRINSICS = ("name", "duration", "type", "timestamp", "totalTime", "error")
+TRANS_EVENT_INTRINSICS = ("name", "duration", "type", "timestamp", "totalTime", "error", "nr.apdexPerfZone", "apdexPerfZone")
 TRANS_EVENT_AGENT_KEYS = [
     "response.status",
     "request.method",
@@ -132,8 +138,8 @@ def normal_wsgi_application(environ, start_response):
     output = "<html><head>header</head><body><p>RESPONSE</p></body></html>"
     output = output.encode("UTF-8")
 
-    add_custom_parameter(USER_ATTRS[0], "test_value")
-    add_custom_parameter(USER_ATTRS[1], "test_value")
+    add_custom_attribute(USER_ATTRS[0], "test_value")
+    add_custom_attribute(USER_ATTRS[1], "test_value")
 
     response_headers = [("Content-Type", "text/html; charset=utf-8"), ("Content-Length", str(len(output)))]
     start_response(status, response_headers)
