@@ -24,12 +24,18 @@ from testing_support.fixtures import (
     validate_attributes_complete,
     validate_custom_event_count,
     validate_custom_event_in_application_stats_engine,
-    validate_custom_parameters,
-    validate_non_transaction_error_event,
     validate_request_params_omitted,
-    validate_transaction_errors,
     validate_tt_segment_params,
 )
+from testing_support.validators.validate_custom_parameters import (
+    validate_custom_parameters,
+)
+from testing_support.validators.validate_non_transaction_error_event import (
+    validate_non_transaction_error_event,
+)
+from testing_support.validators.validate_transaction_errors import (
+    validate_transaction_errors,
+)
 
 from newrelic.api.application import application_instance as application
 from newrelic.api.background_task import background_task
@@ -38,7 +44,7 @@ from newrelic.api.message_trace import MessageTrace
 from newrelic.api.settings import STRIP_EXCEPTION_MESSAGE
 from newrelic.api.time_trace import notice_error
 from newrelic.api.transaction import (
-    add_custom_parameter,
+    add_custom_attribute,
     capture_request_params,
     current_transaction,
     record_custom_event,
@@ -396,7 +402,7 @@ _test_transaction_settings_hsm_enabled = {
 @validate_custom_parameters(required_params=[("key", "value")])
 @background_task()
 def test_other_transaction_custom_parameters_hsm_disabled():
-    add_custom_parameter("key", "value")
+    add_custom_attribute("key", "value")
 
 
 @override_application_settings(_test_transaction_settings_hsm_disabled)
@@ -404,14 +410,14 @@ def test_other_transaction_custom_parameters_hsm_disabled():
 @background_task()
 def test_other_transaction_multiple_custom_parameters_hsm_disabled():
     transaction = current_transaction()
-    transaction.add_custom_parameters([("key-1", "value-1"), ("key-2", "value-2")])
+    transaction.add_custom_attributes([("key-1", "value-1"), ("key-2", "value-2")])
 
 
 @override_application_settings(_test_transaction_settings_hsm_enabled)
 @validate_custom_parameters(forgone_params=[("key", "value")])
 @background_task()
 def test_other_transaction_custom_parameters_hsm_enabled():
-    add_custom_parameter("key", "value")
+    add_custom_attribute("key", "value")
 
 
 @override_application_settings(_test_transaction_settings_hsm_enabled)
@@ -419,7 +425,7 @@ def test_other_transaction_custom_parameters_hsm_enabled():
 @background_task()
 def test_other_transaction_multiple_custom_parameters_hsm_enabled():
     transaction = current_transaction()
-    transaction.add_custom_parameters([("key-1", "value-1"), ("key-2", "value-2")])
+    transaction.add_custom_attributes([("key-1", "value-1"), ("key-2", "value-2")])
 
 
 class TestException(Exception):
@@ -434,7 +440,7 @@ _test_exception_name = "%s:%s" % (__name__, TestException.__name__)
 @validate_custom_parameters(required_params=[("key-1", "value-1")])
 @background_task()
 def test_other_transaction_error_parameters_hsm_disabled():
-    add_custom_parameter("key-1", "value-1")
+    add_custom_attribute("key-1", "value-1")
     try:
         raise TestException("test message")
     except Exception:
@@ -448,7 +454,7 @@ def test_other_transaction_error_parameters_hsm_disabled():
 @validate_custom_parameters(forgone_params=[("key-1", "value-1")])
 @background_task()
 def test_other_transaction_error_parameters_hsm_enabled():
-    add_custom_parameter("key-1", "value-1")
+    add_custom_attribute("key-1", "value-1")
     try:
         raise TestException("test message")
     except Exception:
