@@ -19,7 +19,11 @@ from testing_support.fixtures import (
     cat_enabled,
     make_synthetics_header,
     override_application_settings,
+)
+from testing_support.validators.validate_synthetics_event import (
     validate_synthetics_event,
+)
+from testing_support.validators.validate_synthetics_transaction_trace import (
     validate_synthetics_transaction_trace,
 )
 
