@@ -12,17 +12,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import pytest
-import random
+import threading
 
+import pytest
+from testing_support.fixtures import collector_available_fixture  # noqa
 from testing_support.fixtures import (
     code_coverage_fixture,
     collector_agent_registration_fixture,
-    collector_available_fixture,
 )
 from testing_support.mock_external_grpc_server import MockExternalgRPCServer
+
 from newrelic.common.streaming_utils import StreamBuffer
-import threading
 
 CONDITION_CLS = type(threading.Condition())
 
@@ -40,20 +40,19 @@ _default_settings = {
     "agent_limits.errors_per_harvest": 100,
     "distributed_tracing.enabled": True,
     "infinite_tracing.trace_observer_host": "nr-internal.aws-us-east-2.tracing.staging-edge.nr-data.net",
+    "infinite_tracing.compression": True,
     "debug.connect_span_stream_in_developer_mode": True,
 }
 
 collector_agent_registration = collector_agent_registration_fixture(
-    app_name="Python Agent Test (agent_streaming)",
-    default_settings=_default_settings
+    app_name="Python Agent Test (agent_streaming)", default_settings=_default_settings
 )
 
 
 @pytest.fixture(scope="module")
 def grpc_app_server():
-    port = random.randint(50000, 50099)
-    with MockExternalgRPCServer(port=port) as server:
-        yield server, port
+    with MockExternalgRPCServer() as server:
+        yield server, server.port
 
 
 @pytest.fixture(scope="module")
@@ -83,5 +82,34 @@ def buffer_empty_event(monkeypatch):
     def condition(*args, **kwargs):
         return SetEventOnWait(event, *args, **kwargs)
 
-    monkeypatch.setattr(StreamBuffer, 'condition', condition)
+    monkeypatch.setattr(StreamBuffer, "condition", condition)
     return event
+
+
+@pytest.fixture(scope="session", params=[pytest.param(True, id="batching"), pytest.param(False, id="nonbatching")])
+def batching(request):
+    return request.param
+
+
+@pytest.fixture(scope="function")
+def spans_received():
+    from _test_handler import SPANS_RECEIVED
+
+    SPANS_RECEIVED.clear()
+    return SPANS_RECEIVED
+
+
+@pytest.fixture(scope="function")
+def span_batches_received():
+    from _test_handler import SPAN_BATCHES_RECEIVED
+
+    SPAN_BATCHES_RECEIVED.clear()
+    return SPAN_BATCHES_RECEIVED
+
+
+@pytest.fixture(scope="function")
+def spans_processed_event():
+    from _test_handler import SPANS_PROCESSED_EVENT
+
+    SPANS_PROCESSED_EVENT.clear()
+    return SPANS_PROCESSED_EVENT
