@@ -44,11 +44,12 @@ try:
     reload
 except NameError:
     # python 3.x
-    from imp import reload  # pylint: disable=W0402
+    from importlib import reload
 
 
 class FakeProtos(object):
     Span = object()
+    SpanBatch = object()
 
 
 sys.modules["grpc"] = object()
