@@ -15,7 +15,7 @@
 from newrelic.api.background_task import background_task
 from newrelic.api.transaction import ignore_transaction, end_of_transaction
 
-from testing_support.fixtures import validate_transaction_metrics
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
 from testing_support.validators.validate_code_level_metrics import validate_code_level_metrics
 
 from tasks import add, tsum
