@@ -15,10 +15,8 @@
 import sys
 
 import pytest
-import uvloop
-from testing_support.fixtures import (
-    function_not_called,
-    override_generic_settings,
+from testing_support.fixtures import function_not_called, override_generic_settings
+from testing_support.validators.validate_transaction_metrics import (
     validate_transaction_metrics,
 )
 
@@ -34,6 +32,14 @@ from newrelic.api.time_trace import current_trace
 from newrelic.core.config import global_settings
 from newrelic.core.trace_cache import trace_cache
 
+# uvloop is not available on PyPy.
+try:
+    import uvloop
+
+    loop_policies = (None, uvloop.EventLoopPolicy())
+except ImportError:
+    loop_policies = (None,)
+
 
 @function_trace("waiter3")
 async def child():
@@ -88,7 +94,7 @@ async def _test(asyncio, schedule, nr_enabled=True):
     return trace
 
 
-@pytest.mark.parametrize("loop_policy", (None, uvloop.EventLoopPolicy()))
+@pytest.mark.parametrize("loop_policy", loop_policies)
 @pytest.mark.parametrize(
     "schedule",
     (
@@ -125,7 +131,7 @@ def test_context_propagation(event_loop, schedule, loop_policy):
     # The agent should have removed all traces from the cache since
     # run_until_complete has terminated (all callbacks scheduled inside the
     # task have run)
-    assert not trace_cache()._cache
+    assert not trace_cache()
 
     # Assert that no exceptions have occurred
     assert not exceptions, exceptions
@@ -283,7 +289,7 @@ def test_transaction_exit_trace_cache(event_loop, fg):
 
     # The agent should have removed all traces from the cache since
     # run_until_complete has terminated
-    assert not trace_cache()._cache
+    assert not trace_cache()
 
     # Assert that no exceptions have occurred
     assert not exceptions, exceptions
