@@ -12,23 +12,27 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from testing_support.fixtures import (code_coverage_fixture,  # noqa
-        collector_agent_registration_fixture, collector_available_fixture)
+from testing_support.fixture.event_loop import event_loop
+from testing_support.fixtures import code_coverage_fixture  # noqa
+from testing_support.fixtures import (
+    collector_agent_registration_fixture,
+    collector_available_fixture,
+)
 
 _default_settings = {
-    'transaction_tracer.explain_threshold': 0.0,
-    'transaction_tracer.transaction_threshold': 0.0,
-    'transaction_tracer.stack_trace_threshold': 0.0,
-    'debug.log_data_collector_payloads': True,
-    'debug.record_transaction_failure': True,
+    "transaction_tracer.explain_threshold": 0.0,
+    "transaction_tracer.transaction_threshold": 0.0,
+    "transaction_tracer.stack_trace_threshold": 0.0,
+    "debug.log_data_collector_payloads": True,
+    "debug.record_transaction_failure": True,
 }
 
 collector_agent_registration = collector_agent_registration_fixture(
-        app_name='Python Agent Test (datastore_asyncpg)',
-        default_settings=_default_settings)
+    app_name="Python Agent Test (datastore_asyncpg)", default_settings=_default_settings
+)
 
 _coverage_source = [
-    'newrelic.hooks.database_asyncpg',
+    "newrelic.hooks.database_asyncpg",
 ]
 
 code_coverage = code_coverage_fixture(source=_coverage_source)
