@@ -17,10 +17,8 @@ import asyncio
 import asyncpg
 import pytest
 from testing_support.db_settings import postgresql_settings
-from testing_support.fixtures import (
-    override_application_settings,
-    validate_transaction_metrics,
-)
+from testing_support.fixtures import override_application_settings
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
 from testing_support.util import instance_hostname
 
 from newrelic.api.background_task import background_task
