@@ -12,19 +12,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import asyncio
 import os
-import random
 from io import BytesIO
 
 import asyncpg
 import pytest
 from testing_support.db_settings import postgresql_settings
-from testing_support.fixtures import (
+from testing_support.util import instance_hostname
+from testing_support.validators.validate_transaction_metrics import (
     validate_transaction_metrics,
+)
+from testing_support.validators.validate_tt_collector_json import (
     validate_tt_collector_json,
 )
-from testing_support.util import instance_hostname
 
 from newrelic.api.background_task import background_task
 
