@@ -18,7 +18,7 @@ import sys
 
 is_pypy = hasattr(sys, 'pypy_version_info')
 
-from testing_support.fixtures import validate_transaction_metrics
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
 from testing_support.validators.validate_database_trace_inputs import validate_database_trace_inputs
 
 from newrelic.api.background_task import background_task
