@@ -21,8 +21,8 @@ from testing_support.external_fixtures import (
 from testing_support.fixtures import (
     cat_enabled,
     override_application_settings,
-    validate_transaction_metrics,
 )
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
 from testing_support.validators.validate_cross_process_headers import (
     validate_cross_process_headers,
 )
