@@ -25,7 +25,8 @@ from testing_support.external_fixtures import (
     cache_outgoing_headers,
     insert_incoming_headers,
 )
-from testing_support.fixtures import cat_enabled, validate_transaction_metrics
+from testing_support.fixtures import cat_enabled
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
 from testing_support.validators.validate_cross_process_headers import (
     validate_cross_process_headers,
 )
