@@ -21,7 +21,6 @@ from testing_support.external_fixtures import (
 from testing_support.fixtures import (
     cat_enabled,
     override_application_settings,
-    validate_transaction_metrics,
 )
 from testing_support.validators.validate_cross_process_headers import (
     validate_cross_process_headers,
@@ -29,6 +28,7 @@ from testing_support.validators.validate_cross_process_headers import (
 from testing_support.validators.validate_external_node_params import (
     validate_external_node_params,
 )
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
 
 from newrelic.api.background_task import background_task
 
