@@ -15,6 +15,7 @@
 import asyncio
 
 import pytest
+from testing_support.fixture.event_loop import event_loop as loop
 from testing_support.fixtures import (
     code_coverage_fixture,
     collector_agent_registration_fixture,
@@ -46,8 +47,3 @@ def httpx():
     import httpx
 
     return httpx
-
-
-@pytest.fixture(scope="session")
-def loop():
-    return asyncio.get_event_loop()
