@@ -17,9 +17,11 @@ import webtest
 
 from newrelic.packages import six
 
-from testing_support.fixtures import (validate_transaction_errors,
-        override_application_settings, override_ignore_status_codes)
+from testing_support.fixtures import (
+        override_application_settings, 
+        override_ignore_status_codes)
 from testing_support.validators.validate_code_level_metrics import validate_code_level_metrics
+from testing_support.validators.validate_transaction_errors import validate_transaction_errors
 
 import cherrypy
 
