@@ -14,7 +14,7 @@
 
 import webtest
 
-from testing_support.fixtures import validate_transaction_errors
+from testing_support.validators.validate_transaction_errors import validate_transaction_errors
 from testing_support.validators.validate_code_level_metrics import validate_code_level_metrics
 
 import cherrypy
