@@ -12,8 +12,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from testing_support.fixtures import (validate_transaction_metrics,
-    validate_transaction_errors, override_application_settings)
+from testing_support.fixtures import override_application_settings
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
+from testing_support.validators.validate_transaction_errors import validate_transaction_errors
 
 from testing_support.validators.validate_code_level_metrics import validate_code_level_metrics
 
