@@ -15,7 +15,8 @@
 import json
 
 import pytest
-from testing_support.fixtures import dt_enabled, validate_transaction_metrics
+from testing_support.fixtures import dt_enabled
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
 from testing_support.validators.validate_span_events import validate_span_events
 
 
