@@ -13,7 +13,7 @@
 # limitations under the License.
 
 import pytest
-from testing_support.fixtures import validate_transaction_metrics
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
 from testing_support.validators.validate_code_level_metrics import validate_code_level_metrics
 
 pytestmark = pytest.mark.custom_app
