@@ -23,9 +23,8 @@ from testing_support.db_settings import rabbitmq_settings
 from testing_support.fixtures import (
     cat_enabled,
     override_application_settings,
-    validate_transaction_metrics,
 )
-
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
 from newrelic.api.background_task import background_task
 from newrelic.api.transaction import current_transaction
 
