@@ -13,7 +13,7 @@
 # limitations under the License.
 
 from mako.template import Template
-from testing_support.fixtures import validate_transaction_metrics
+from testing_support.validators.validate_transaction_metrics import validate_transaction_metrics
 from newrelic.api.background_task import background_task
 
 
